#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-retrie-plugin
version:              1.0.1.0
visibility:           public
id:                   hls-retrie-plugin-1.0.1.0-20NkMudZS6MHqdapzVumQH
key:                  hls-retrie-plugin-1.0.1.0-20NkMudZS6MHqdapzVumQH
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Retrie integration plugin for Haskell Language Server
category:             Development
abi:                  abae57dce4ec1716ed52c25eecce661b
exposed:              True
exposed-modules:      Ide.Plugin.Retrie
import-dirs:          /usr/lib/ghc-8.10.5/site-local/hls-retrie-plugin-1.0.1.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hls-retrie-plugin-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hls-retrie-plugin-1.0.1.0
hs-libraries:         HShls-retrie-plugin-1.0.1.0-20NkMudZS6MHqdapzVumQH
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ base-4.14.2.0
    containers-0.6.4.1 deepseq-1.4.4.0 directory-1.3.6.0
    extra-1.7.9-4atxCqewDRnKsFBrL9ak4x ghc-8.10.5
    ghc-api-compat-8.6-3TY3o2v9hFDBa7VjHV0kS9
    ghcide-1.4.0.1-5stW1V6MhVBGeCRHZSaIfO
    hashable-1.3.2.0-GpzwVyCMdDv8NwdC61S1EE
    hls-plugin-api-1.1.0.2-6o7hY0E5YQuCD8G4Bf3t3o
    lsp-1.2.0.0-JYjHpvPu1SW4k7gGYBb5ES
    lsp-types-1.2.0.0-926l9WtteBxBKACgKH5KZf
    retrie-0.1.1.1-D5IU5pYNOYi2jNPU304BuZ
    safe-exceptions-0.1.7.1-5k5YUvh9EUEA8260dxkQvv text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya

haddock-interfaces:
    /usr/share/doc/haskell-hls-retrie-plugin/html/hls-retrie-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-retrie-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

